==> gsequencer_3.18.2.orig.tar.gz: gsequencer-3.18.2/ags/app/machine/ags_audiorec_callbacks.h <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2020 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __AGS_AUDIOREC_CALLBACKS_H__
#define __AGS_AUDIOREC_CALLBACKS_H__

#include <glib.h>
#include <glib-object.h>

#include <gtk/gtk.h>

#include <ags/libags.h>
#include <ags/libags-audio.h>

#include <ags/libags-gui.h>

#include <ags/app/machine/ags_audiorec.h>

G_BEGIN_DECLS

void ags_audiorec_parent_set_callback(GtkWidget *widget, GtkWidget *old_parent, AgsAudiorec *audiorec);

void ags_audiorec_open_callback(GtkWidget *button, AgsAudiorec *audiorec);

void ags_audiorec_keep_data_callback(GtkWidget *button, AgsAudiorec *audiorec);
void ags_audiorec_replace_data_callback(GtkWidget *button, AgsAudiorec *audiorec);
void ags_audiorec_mix_data_callback(GtkWidget *button, AgsAudiorec *audiorec);

G_END_DECLS

#endif /*__AGS_AUDIOREC_CALLBACKS_H__*/

==> gsequencer_8.2.9.orig.tar.gz: gsequencer-8.2.9/ags/app/machine/ags_audiorec_callbacks.h <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2024 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __AGS_AUDIOREC_CALLBACKS_H__
#define __AGS_AUDIOREC_CALLBACKS_H__

#include <glib.h>
#include <glib-object.h>

#include <gtk/gtk.h>

#include <ags/libags.h>
#include <ags/libags-audio.h>

#include <ags/libags-gui.h>

#include <ags/app/machine/ags_audiorec.h>

G_BEGIN_DECLS

void ags_audiorec_update_ui_callback(GObject *ui_provider,
				     AgsAudiorec *audiorec);

void ags_audiorec_open_callback(GtkWidget *button, AgsAudiorec *audiorec);

void ags_audiorec_keep_data_callback(GtkWidget *button, AgsAudiorec *audiorec);
void ags_audiorec_replace_data_callback(GtkWidget *button, AgsAudiorec *audiorec);
void ags_audiorec_mix_data_callback(GtkWidget *button, AgsAudiorec *audiorec);

G_END_DECLS

#endif /*__AGS_AUDIOREC_CALLBACKS_H__*/
